==> moodle_1.3.1.orig.tar.gz: moodle/lang/no/workshop.php <==
<?PHP // $Id: workshop.php,v 1.5 2004/04/14 11:32:45 stigbjarne Exp $ 
      // workshop.php - created with Moodle 1.2 (2004032000)


$string['absent'] = 'Fravr';
$string['accumulative'] = 'Akkumulerende';
$string['action'] = 'Handling';
$string['addacomment'] = 'Legg til kommentar';
$string['afterdeadline'] = 'Etter fristen: $a';
$string['agreetothisassessment'] = 'Godkjenn denne vurderingen';
$string['allgradeshaveamaximumof'] = 'Alle karakterer har en maksimumverdi p: $a';
$string['allowresubmit'] = 'Tillat ny innlevering';
$string['alreadyinphase'] = 'Allerede i fase $a';
$string['amendassessmentelements'] = 'Forbedre vurderte elementer';
$string['amendtitle'] = 'Forbedre tittelen';
$string['analysisofassessments'] = 'Analyse av vurderinger';
$string['assess'] = 'Vurder';
$string['assessedon'] = 'Vurdering av $a';
$string['assessment'] = 'Vurdering';
$string['assessmentby'] = 'Vurdert av $a';
$string['assessmentdropped'] = 'Vurdering utelatt';
$string['assessmentgrade'] = 'Vurdering: Karakter $a';
$string['assessmentnotyetagreed'] = 'Vurdering ikke godkjent enda';
$string['assessmentofresubmission'] = 'Dette er vurdering av en revidert del av arbeidet.<br />Skjemaet her er fylt med dine tidligere karakterer og komentarer. <br />Vennligst forbedre disse etter at du har sett p det reviderte arbeidet.';
$string['assessmentofthissubmission'] = 'Vurdering av denne innleveringen';
$string['assessments'] = 'Vurderinger';
$string['assessmentsareok'] = 'Vurderinger er OK';
$string['assessmentsby'] = 'Vurderinger av $a';
$string['assessmentsdone'] = 'Vurdering fullfrt';
$string['assessmentsexcluded'] = 'Antallet vurderinger ekskludert for denne $a';
$string['assessmentsmustbeagreed'] = 'Vurdering m godkjennes';
$string['assessmentwasagreedon'] = 'Vurderingen ble godkjent $a';
$string['assessor'] = 'Vurderer';
$string['assessthissubmission'] = 'Vurder denne innleveringen';
$string['assignmentnotinthecorrectphase'] = 'Vurderingen er ikke i den riktige fasen';
$string['authorofsubmission'] = 'Forfatter av innlevering';
$string['averageerror'] = 'Feil med gjennomsnitt';
$string['awaitinggradingbyteacher'] = 'Venter p karakter fra $a';
$string['beforedeadline'] = 'Fr fristen: $a';
$string['calculationoffinalgrades'] = 'Utregning av endelige karakterer';
$string['closeassignment'] = 'Steng mulighet for innlevering';
$string['comment'] = 'Kommentar';
$string['commentby'] = 'Kommentert av';
$string['confirmdeletionofthisitem'] = 'Bekreft sletting av denne $a';
$string['correct'] = 'Riktig';
$string['criterion'] = 'Kriterier';
$string['deadline'] = 'Frist';
$string['deadlineis'] = 'Fristen er $a';
$string['delete'] = 'Slett';
$string['deleting'] = 'Sletter';
$string['description'] = 'Beskrivelse';
$string['detailsofassessment'] = 'Detaljer om vurderingen';
$string['disagreewiththisassessment'] = 'Avvis denne vurderingen';
$string['displayoffinalgrades'] = 'Vis endelige karakterer';
$string['dontshowgrades'] = 'Ikke vis karakterer';
$string['edit'] = 'Rediger';
$string['editacomment'] = 'Rediger en kommentar';
$string['editingassessmentelements'] = 'Rediger komponenter i det som er vurdert';
$string['element'] = 'Element';
$string['elementweight'] = 'Vekting av element';
$string['excellent'] = 'Utmerket';
$string['excludingdroppedassessments'] = 'Ekskluder droppede vurderinger';
$string['expectederror'] = 'Forventet feilverdi hvis';
$string['feedbackgoeshere'] = 'Tilbakemelding skrives her';
$string['generalcomment'] = 'Generell kommentar';
$string['good'] = 'Bra';
$string['grade'] = 'Karakter';
$string['gradeassessment'] = 'Karaktervurdering';
$string['graded'] = 'Gitt karakter';
$string['gradedbyteacher'] = 'Gitt karakter av $a';
$string['gradeforassessments'] = 'Karakter for vurdering';
$string['gradeforbias'] = 'Karakter for nytralitet';
$string['gradeforreliability'] = 'Karakter for troverdighet';
$string['gradeforstudentsassessment'] = 'Karakter for studentens vurdering';
$string['gradeforsubmission'] = 'Karakter for innlevering';
$string['gradeofsubmission'] = 'Karakter p innlevering: $a';
$string['gradetable'] = 'Karaktertabell';
$string['gradingstrategy'] = 'Karakterstrategi';
$string['hidegradesbeforeagreement'] = 'Skjul karakterer fr godkjenning';
$string['hidenamesfromstudents'] = 'Skjul navn for $a';
$string['includeteachersgrade'] = 'Inkluder lrerens karakter';
$string['incorrect'] = 'Uriktig';
$string['iteration'] = 'Repetering $a fullfrt';
$string['leaguetable'] = 'Tabelloversikt over innleverte arbeider';
$string['listassessments'] = 'Liste over vurderinger';
$string['listofallsubmissions'] = 'Liste over alle innleveringer';
$string['liststudentsassessments'] = 'Liste over studentenes vurderinger';
$string['loadingforteacherassessments'] = 'Laster opp for $a vurderinger';
$string['mail1'] = 'Din oppgave \'$a\' er vurdert av';
$string['mail10'] = 'Du fr tilgang til det i workshop-oppgaven';
$string['mail2'] = 'Kommentarer og karakterer kan leses i workshop-oppgaven \'$a\'';
$string['mail3'] = 'Du kan se det i workshop-oppgaven din';
$string['mail4'] = 'En kommentar er lagt til oppgaven \'$a\' av';
$string['mail5'] = 'Den nye kommentaren kan leses i workshop-oppgaven \'$a\'';
$string['mail6'] = 'Din vurdering av oppgaven \'$a\' er revurdert';
$string['mail7'] = 'Kommentaren gitt av $a kan leses i workshop-oppgaven';
$string['mail8'] = 'Oppgaven $a er et revidert arbeide.';
$string['mail9'] = 'Vennligst vurder den i workshop-oppgaven $a';
$string['managingassignment'] = 'Administrer oppgaven';
$string['maximumsize'] = 'Maksimum strrelse';
$string['modulename'] = 'Workshop';
$string['modulenameplural'] = 'Workshops';
$string['movingtophase'] = 'Gr over til fase $a';
$string['namesnotshowntostudents'] = 'Navn vises ikke til $a';
$string['newassessments'] = 'Nye vurderinger';
$string['newgradings'] = 'Nye karakterer';
$string['newsubmissions'] = 'Nye innleveringer';
$string['noassessments'] = 'Ingen vurdering';
$string['noassessmentsdone'] = 'Ingen vurdering enda';
$string['nosubmission'] = 'Ingen innlevering';
$string['nosubmissionsavailableforassessment'] = 'Ingen innleveringer tilgjengelig for vurdering';
$string['notavailable'] = 'Ikke tilgjengelig';
$string['noteonassessmentelements'] = 'Merk at karaktersettingen er delt inn i flere \'elementer for vurdering\'.<br>Dette gjr karaktersettingen enklere og mer konsekvent.Som lrer m du legge til disse<br>elementene fr du gjr workshopen tilgjengelig for studentene.Dette gjres ved <br>klikke p workshopen p studiesiden. Hvis ingen elementer er lagt til blir du bedt om<br> legge dem til. Du kan endre antallet elementer vha. skjermbildet \'Rediger workshop\',<br>elementene i seg selv kan hentes fra skjermbildet \'Administrer workshopen\'.';
$string['notgraded'] = 'Ikke satt karakter';
$string['notitlegiven'] = 'Ingen tittel satt';
$string['numberofassessmentelements'] = 'Antallet kommentarer, vurderingselementer, karakterskalaer, kriterier eller kategorier i en rubrikk';
$string['numberofassessments'] = 'Antall vurderinger';
$string['numberofassessmentschanged'] = 'Antall vurderinger endret: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'Antall vurderinger av studentinnleveringer';
$string['numberofassessmentsofteachersexamples'] = 'Antall vurderinger av eksempler fra lrer';
$string['numberofentries'] = 'Antall oppfringer';
$string['numberofnegativeresponses'] = 'Antall negative svar';
$string['numberofsubmissions'] = 'Antall innleveringer: $a';
$string['on'] = 'av $a';
$string['openassignment'] = 'pne workshop';
$string['optionaladjustment'] = 'Valgfrie innstillinger';
$string['optionforpeergrade'] = 'Valg om vurdering studentene imellom';
$string['optionsusedinanalysis'] = 'Innstillinger som brukes i analyser';
$string['overallgrade'] = 'Samlet karakter';
$string['overallpeergrade'] = 'Samlet karakter fra medstudentene: $a';
$string['overallteachergrade'] = 'Samlet karakter fra lrer: $a';
$string['ownwork'] = 'Eget arbeide';
$string['percentageofassessments'] = 'Prosent av vurderinger som skal droppes';
$string['phase'] = 'Fase';
$string['phase1'] = 'Lag workshop';
$string['phase1short'] = 'Lag';
$string['phase2'] = 'Tillat $a innleveringer';
$string['phase2short'] = 'Innleveringer';
$string['phase3'] = 'Tillat $a innleveringer og vurderinger';
$string['phase3short'] = 'Begge';
$string['phase4'] = 'Tillat $a vurderinger';
$string['phase4short'] = 'Vurderinger';
$string['phase5'] = 'Utregning av endelige karakterer';
$string['phase5short'] = 'Utregning';
$string['phase6'] = 'Vis endelige karakterer';
$string['phase6short'] = 'Vis karakterer';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Vennligst vurder disse eksemplene fra $a';
$string['pleaseassessthesestudentsubmissions'] = 'Vennligst vurder disse $a innleveringene';
$string['pleaseassessyoursubmissions'] = 'Vennligst vurder din(e) innlevering(er)';
$string['poor'] = 'Drlig';
$string['present'] = 'Gjeldende';
$string['reasonforadjustment'] = 'rsak til endring';
$string['reassess'] = 'Vurder p nytt';
$string['repeatanalysis'] = 'Gjenta analyse';
$string['reply'] = 'Svar';
$string['returnto'] = 'G tilbake til';
$string['returntosubmissionpage'] = 'G tilbake til siden for innlevering';
$string['rubric'] = 'Rubrikk';
$string['savedok'] = 'Lagret OK';
$string['savemyassessment'] = 'Lagre min vurdering';
$string['savemycomment'] = 'Lagre min kommentar';
$string['savemygrading'] = 'Lagre min karaktersetting';
$string['scale10'] = 'Score av 10';
$string['scale100'] = 'Score av 100';
$string['scale20'] = 'Score av 20';
$string['scalecorrect'] = 'To poengs \'Riktig/Galt\'-skala';
$string['scaleexcellent4'] = 'Fire poengs \'Svrt bra/Svrt drlig\'-skala';
$string['scaleexcellent5'] = 'Fem poengs \'Svrt bra/Svrt drlig\'-skala';
$string['scaleexcellent7'] = 'Syv poengs \'Svrt bra/Svrt drlig\'-skala';
$string['scalegood3'] = 'Tre poengs \'Bra/Drlig\'-skala';
$string['scalepresent'] = 'To poengs \'Til stede/Fravrende\'-skala';
$string['scaleyes'] = 'To poengs \'Ja/Nei\'-skala';
$string['select'] = 'Velg';
$string['selfassessment'] = 'Egenvurdering';
$string['showgrades'] = 'Vis karakterer';
$string['specimenassessmentform'] = 'Eksempelskjema for vurdering';
$string['studentassessments'] = '$a vurderinger';
$string['studentgrades'] = '$a karakterer';
$string['studentsubmissions'] = '$a innleveringer';
$string['studentsubmissionsforassessment'] = '$a studentinnleveringer klare til vurdering';
$string['submission'] = 'Innlevering';
$string['submissions'] = 'Innleveringer';
$string['submissionsnolongerallowed'] = 'Innlevering ikke lenger tillatt';
$string['submissionsused'] = '$a innleveringer brukte i denne tabellen';
$string['submitassignment'] = 'Lever oppgave';
$string['submitassignmentusingform'] = 'Lever din oppgave med dette skjemaet';
$string['submitexampleassignment'] = 'Lever eksempeloppgave';
$string['submitrevisedassignment'] = 'Lever din REVIDERTE oppgave med dette skjemaet';
$string['submitted'] = 'Levert';
$string['submittedby'] = 'Levert av';
$string['suggestedgrade'] = 'Foresltt karakter';
$string['teacherassessments'] = '$a vurderinger';
$string['teacherscomment'] = 'Lrerens kommentar';
$string['teachersgrade'] = 'Lrerens karakter';
$string['teachersubmissionsforassessment'] = '$a lrerinnleveringer klare til vurdering';
$string['thegradeis'] = 'Karakteren er $a';
$string['thereisfeedbackfromtheteacher'] = 'Det har kommet tilbakemelding fra $a';
$string['theseasessmentsaregradedbytheteacher'] = 'Disse vurderingene er karaktersatt av $a';
$string['timeassessed'] = 'Tid vurdert';
$string['title'] = 'Tittel';
$string['typeofscale'] = 'Type skala';
$string['ungradedassessmentsofstudentsubmissions'] = '$a ikke karaktersatte vurderinger av studentinnleveringer';
$string['ungradedassessmentsofteachersubmissions'] = '$a ikke karaktersatte vurderinger av lrerinnleveringer';
$string['verypoor'] = 'Veldig drlig';
$string['view'] = 'Vis';
$string['viewassessmentofteacher'] = 'Vis vurdering av $a';
$string['viewotherassessments'] = 'Vis andre vurderinger';
$string['warningonamendingelements'] = 'ADVARSEL: Det er innsendte vurderinger. <br>Du br IKKE endre antallet elementer, type skala eller elementenes vekting.';
$string['weight'] = 'Vekting';
$string['weightederrorcount'] = 'Feil med sum av vekting: $a';
$string['weightforbias'] = 'Vekting for nytralitet';
$string['weightforgradingofassessments'] = 'Vekting for vurdering av innleveringer';
$string['weightforpeerassessments'] = 'Vekting for medstudentenes vurderinger';
$string['weightforreliability'] = 'Vekting for troverdighet';
$string['weightforteacherassessments'] = 'Vekting for lrervurdering';
$string['weights'] = 'Vekting';
$string['weightsusedforfinalgrade'] = 'Vekting brukt i endelig karakter';
$string['weightsusedforsubmissions'] = 'Vekting for innleveringer';
$string['workshopagreedassessments'] = 'Vurderinger godkjent i workshop';
$string['workshopassessments'] = 'Vurderinger i workshop';
$string['workshopcomments'] = 'Kommentarer i workshop';
$string['workshopfeedback'] = 'Tilbakemeldinger i workshop';
$string['workshopsubmissions'] = 'Innleveringer i workshop';
$string['yourassessments'] = 'Dine vurderinger';
$string['yourassessmentsofexamplesfromtheteacher'] = 'Dine vurderinger av eksempler fra $a';
$string['yourfeedbackgoeshere'] = 'Skriv din tilbakemelding her';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/no/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.2 (2004032000)


$string['absent'] = 'Fravr';
$string['accumulative'] = 'Akkumulerende';
$string['action'] = 'Handling';
$string['addacomment'] = 'Legg til kommentar';
$string['afterdeadline'] = 'Etter fristen: $a';
$string['agreetothisassessment'] = 'Godkjenn denne vurderingen';
$string['allgradeshaveamaximumof'] = 'Alle karakterer har en maksimumverdi p: $a';
$string['allowresubmit'] = 'Tillat ny innlevering';
$string['alreadyinphase'] = 'Allerede i fase $a';
$string['amendassessmentelements'] = 'Forbedre vurderte elementer';
$string['amendtitle'] = 'Forbedre tittelen';
$string['analysisofassessments'] = 'Analyse av vurderinger';
$string['assess'] = 'Vurder';
$string['assessedon'] = 'Vurdering av $a';
$string['assessment'] = 'Vurdering';
$string['assessmentby'] = 'Vurdert av $a';
$string['assessmentdropped'] = 'Vurdering utelatt';
$string['assessmentgrade'] = 'Vurdering: Karakter $a';
$string['assessmentnotyetagreed'] = 'Vurdering ikke godkjent enda';
$string['assessmentofresubmission'] = 'Dette er vurdering av en revidert del av arbeidet.<br />Skjemaet her er fylt med dine tidligere karakterer og komentarer. <br />Vennligst forbedre disse etter at du har sett p det reviderte arbeidet.';
$string['assessmentofthissubmission'] = 'Vurdering av denne innleveringen';
$string['assessments'] = 'Vurderinger';
$string['assessmentsareok'] = 'Vurderinger er OK';
$string['assessmentsby'] = 'Vurderinger av $a';
$string['assessmentsdone'] = 'Vurdering fullfrt';
$string['assessmentsexcluded'] = 'Antallet vurderinger ekskludert for denne $a';
$string['assessmentsmustbeagreed'] = 'Vurdering m godkjennes';
$string['assessmentwasagreedon'] = 'Vurderingen ble godkjent $a';
$string['assessor'] = 'Vurderer';
$string['assessthissubmission'] = 'Vurder denne innleveringen';
$string['assignmentnotinthecorrectphase'] = 'Vurderingen er ikke i den riktige fasen';
$string['authorofsubmission'] = 'Forfatter av innlevering';
$string['averageerror'] = 'Feil med gjennomsnitt';
$string['awaitinggradingbyteacher'] = 'Venter p karakter fra $a';
$string['beforedeadline'] = 'Fr fristen: $a';
$string['calculationoffinalgrades'] = 'Utregning av endelige karakterer';
$string['closeassignment'] = 'Steng mulighet for innlevering';
$string['comment'] = 'Kommentar';
$string['commentby'] = 'Kommentert av';
$string['confirmdeletionofthisitem'] = 'Bekreft sletting av denne $a';
$string['correct'] = 'Riktig';
$string['criterion'] = 'Kriterier';
$string['deadline'] = 'Frist';
$string['deadlineis'] = 'Fristen er $a';
$string['delete'] = 'Slett';
$string['deleting'] = 'Sletter';
$string['description'] = 'Beskrivelse';
$string['detailsofassessment'] = 'Detaljer om vurderingen';
$string['disagreewiththisassessment'] = 'Avvis denne vurderingen';
$string['displayoffinalgrades'] = 'Vis endelige karakterer';
$string['dontshowgrades'] = 'Ikke vis karakterer';
$string['edit'] = 'Rediger';
$string['editacomment'] = 'Rediger en kommentar';
$string['editingassessmentelements'] = 'Rediger komponenter i det som er vurdert';
$string['element'] = 'Element';
$string['elementweight'] = 'Vekting av element';
$string['excellent'] = 'Utmerket';
$string['excludingdroppedassessments'] = 'Ekskluder droppede vurderinger';
$string['expectederror'] = 'Forventet feilverdi hvis';
$string['feedbackgoeshere'] = 'Tilbakemelding skrives her';
$string['generalcomment'] = 'Generell kommentar';
$string['good'] = 'Bra';
$string['grade'] = 'Karakter';
$string['gradeassessment'] = 'Karaktervurdering';
$string['graded'] = 'Gitt karakter';
$string['gradedbyteacher'] = 'Gitt karakter av $a';
$string['gradeforassessments'] = 'Karakter for vurdering';
$string['gradeforbias'] = 'Karakter for nytralitet';
$string['gradeforreliability'] = 'Karakter for troverdighet';
$string['gradeforstudentsassessment'] = 'Karakter for studentens vurdering';
$string['gradeforsubmission'] = 'Karakter for innlevering';
$string['gradeofsubmission'] = 'Karakter p innlevering: $a';
$string['gradetable'] = 'Karaktertabell';
$string['gradingstrategy'] = 'Karakterstrategi';
$string['hidegradesbeforeagreement'] = 'Skjul karakterer fr godkjenning';
$string['hidenamesfromstudents'] = 'Skjul navn for $a';
$string['includeteachersgrade'] = 'Inkluder lrerens karakter';
$string['incorrect'] = 'Uriktig';
$string['iteration'] = 'Repetering $a fullfrt';
$string['leaguetable'] = 'Tabelloversikt over innleverte arbeider';
$string['listassessments'] = 'Liste over vurderinger';
$string['listofallsubmissions'] = 'Liste over alle innleveringer';
$string['liststudentsassessments'] = 'Liste over studentenes vurderinger';
$string['loadingforteacherassessments'] = 'Laster opp for $a vurderinger';
$string['mail1'] = 'Din oppgave \'$a\' er vurdert av';
$string['mail10'] = 'Du fr tilgang til det i workshop-oppgaven';
$string['mail2'] = 'Kommentarer og karakterer kan leses i workshop-oppgaven \'$a\'';
$string['mail3'] = 'Du kan se det i workshop-oppgaven din';
$string['mail4'] = 'En kommentar er lagt til oppgaven \'$a\' av';
$string['mail5'] = 'Den nye kommentaren kan leses i workshop-oppgaven \'$a\'';
$string['mail6'] = 'Din vurdering av oppgaven \'$a\' er revurdert';
$string['mail7'] = 'Kommentaren gitt av $a kan leses i workshop-oppgaven';
$string['mail8'] = 'Oppgaven $a er et revidert arbeide.';
$string['mail9'] = 'Vennligst vurder den i workshop-oppgaven $a';
$string['managingassignment'] = 'Administrer oppgaven';
$string['maximumsize'] = 'Maksimum strrelse';
$string['modulename'] = 'Workshop';
$string['modulenameplural'] = 'Workshops';
$string['movingtophase'] = 'Gr over til fase $a';
$string['namesnotshowntostudents'] = 'Navn vises ikke til $a';
$string['newassessments'] = 'Nye vurderinger';
$string['newgradings'] = 'Nye karakterer';
$string['newsubmissions'] = 'Nye innleveringer';
$string['noassessments'] = 'Ingen vurdering';
$string['noassessmentsdone'] = 'Ingen vurdering enda';
$string['nosubmission'] = 'Ingen innlevering';
$string['nosubmissionsavailableforassessment'] = 'Ingen innleveringer tilgjengelig for vurdering';
$string['notavailable'] = 'Ikke tilgjengelig';
$string['noteonassessmentelements'] = 'Merk at karaktersettingen er delt inn i flere \'elementer for vurdering\'.<br />Dette gjr karaktersettingen enklere og mer konsekvent.Som lrer m du legge til disse<br />elementene fr du gjr workshopen tilgjengelig for studentene.Dette gjres ved <br />klikke p workshopen p studiesiden. Hvis ingen elementer er lagt til blir du bedt om<br /> legge dem til. Du kan endre antallet elementer vha. skjermbildet \'Rediger workshop\',<br />elementene i seg selv kan hentes fra skjermbildet \'Administrer workshopen\'.';
$string['notgraded'] = 'Ikke satt karakter';
$string['notitlegiven'] = 'Ingen tittel satt';
$string['numberofassessmentelements'] = 'Antallet kommentarer, vurderingselementer, karakterskalaer, kriterier eller kategorier i en rubrikk';
$string['numberofassessments'] = 'Antall vurderinger';
$string['numberofassessmentschanged'] = 'Antall vurderinger endret: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'Antall vurderinger av studentinnleveringer';
$string['numberofassessmentsofteachersexamples'] = 'Antall vurderinger av eksempler fra lrer';
$string['numberofentries'] = 'Antall oppfringer';
$string['numberofnegativeresponses'] = 'Antall negative svar';
$string['numberofsubmissions'] = 'Antall innleveringer: $a';
$string['on'] = 'av $a';
$string['openassignment'] = 'pne workshop';
$string['optionaladjustment'] = 'Valgfrie innstillinger';
$string['optionforpeergrade'] = 'Valg om vurdering studentene imellom';
$string['optionsusedinanalysis'] = 'Innstillinger som brukes i analyser';
$string['overallgrade'] = 'Samlet karakter';
$string['overallpeergrade'] = 'Samlet karakter fra medstudentene: $a';
$string['overallteachergrade'] = 'Samlet karakter fra lrer: $a';
$string['ownwork'] = 'Eget arbeide';
$string['percentageofassessments'] = 'Prosent av vurderinger som skal droppes';
$string['phase'] = 'Fase';
$string['phase1'] = 'Lag workshop';
$string['phase1short'] = 'Lag';
$string['phase2'] = 'Tillat $a innleveringer';
$string['phase2short'] = 'Innleveringer';
$string['phase3'] = 'Tillat $a innleveringer og vurderinger';
$string['phase3short'] = 'Begge';
$string['phase4'] = 'Tillat $a vurderinger';
$string['phase4short'] = 'Vurderinger';
$string['phase5'] = 'Utregning av endelige karakterer';
$string['phase5short'] = 'Utregning';
$string['phase6'] = 'Vis endelige karakterer';
$string['phase6short'] = 'Vis karakterer';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Vennligst vurder disse eksemplene fra $a';
$string['pleaseassessthesestudentsubmissions'] = 'Vennligst vurder disse $a innleveringene';
$string['pleaseassessyoursubmissions'] = 'Vennligst vurder din(e) innlevering(er)';
$string['poor'] = 'Drlig';
$string['present'] = 'Gjeldende';
$string['reasonforadjustment'] = 'rsak til endring';
$string['reassess'] = 'Vurder p nytt';
$string['repeatanalysis'] = 'Gjenta analyse';
$string['reply'] = 'Svar';
$string['returnto'] = 'G tilbake til';
$string['returntosubmissionpage'] = 'G tilbake til siden for innlevering';
$string['rubric'] = 'Rubrikk';
$string['savedok'] = 'Lagret OK';
$string['savemyassessment'] = 'Lagre min vurdering';
$string['savemycomment'] = 'Lagre min kommentar';
$string['savemygrading'] = 'Lagre min karaktersetting';
$string['scale10'] = 'Score av 10';
$string['scale100'] = 'Score av 100';
$string['scale20'] = 'Score av 20';
$string['scalecorrect'] = 'To poengs \'Riktig/Galt\'-skala';
$string['scaleexcellent4'] = 'Fire poengs \'Svrt bra/Svrt drlig\'-skala';
$string['scaleexcellent5'] = 'Fem poengs \'Svrt bra/Svrt drlig\'-skala';
$string['scaleexcellent7'] = 'Syv poengs \'Svrt bra/Svrt drlig\'-skala';
$string['scalegood3'] = 'Tre poengs \'Bra/Drlig\'-skala';
$string['scalepresent'] = 'To poengs \'Til stede/Fravrende\'-skala';
$string['scaleyes'] = 'To poengs \'Ja/Nei\'-skala';
$string['select'] = 'Velg';
$string['selfassessment'] = 'Egenvurdering';
$string['showgrades'] = 'Vis karakterer';
$string['specimenassessmentform'] = 'Eksempelskjema for vurdering';
$string['studentassessments'] = '$a vurderinger';
$string['studentgrades'] = '$a karakterer';
$string['studentsubmissions'] = '$a innleveringer';
$string['studentsubmissionsforassessment'] = '$a studentinnleveringer klare til vurdering';
$string['submission'] = 'Innlevering';
$string['submissions'] = 'Innleveringer';
$string['submissionsnolongerallowed'] = 'Innlevering ikke lenger tillatt';
$string['submissionsused'] = '$a innleveringer brukte i denne tabellen';
$string['submitassignment'] = 'Lever oppgave';
$string['submitassignmentusingform'] = 'Lever din oppgave med dette skjemaet';
$string['submitexampleassignment'] = 'Lever eksempeloppgave';
$string['submitrevisedassignment'] = 'Lever din REVIDERTE oppgave med dette skjemaet';
$string['submitted'] = 'Levert';
$string['submittedby'] = 'Levert av';
$string['suggestedgrade'] = 'Foresltt karakter';
$string['teacherassessments'] = '$a vurderinger';
$string['teacherscomment'] = 'Lrerens kommentar';
$string['teachersgrade'] = 'Lrerens karakter';
$string['teachersubmissionsforassessment'] = '$a lrerinnleveringer klare til vurdering';
$string['thegradeis'] = 'Karakteren er $a';
$string['thereisfeedbackfromtheteacher'] = 'Det har kommet tilbakemelding fra $a';
$string['theseasessmentsaregradedbytheteacher'] = 'Disse vurderingene er karaktersatt av $a';
$string['timeassessed'] = 'Tid vurdert';
$string['title'] = 'Tittel';
$string['typeofscale'] = 'Type skala';
$string['ungradedassessmentsofstudentsubmissions'] = '$a ikke karaktersatte vurderinger av studentinnleveringer';
$string['ungradedassessmentsofteachersubmissions'] = '$a ikke karaktersatte vurderinger av lrerinnleveringer';
$string['verypoor'] = 'Veldig drlig';
$string['view'] = 'Vis';
$string['viewassessmentofteacher'] = 'Vis vurdering av $a';
$string['viewotherassessments'] = 'Vis andre vurderinger';
$string['warningonamendingelements'] = 'ADVARSEL: Det er innsendte vurderinger. <br />Du br IKKE endre antallet elementer, type skala eller elementenes vekting.';
$string['weight'] = 'Vekting';
$string['weightederrorcount'] = 'Feil med sum av vekting: $a';
$string['weightforbias'] = 'Vekting for nytralitet';
$string['weightforgradingofassessments'] = 'Vekting for vurdering av innleveringer';
$string['weightforpeerassessments'] = 'Vekting for medstudentenes vurderinger';
$string['weightforreliability'] = 'Vekting for troverdighet';
$string['weightforteacherassessments'] = 'Vekting for lrervurdering';
$string['weights'] = 'Vekting';
$string['weightsusedforfinalgrade'] = 'Vekting brukt i endelig karakter';
$string['weightsusedforsubmissions'] = 'Vekting for innleveringer';
$string['workshopagreedassessments'] = 'Vurderinger godkjent i workshop';
$string['workshopassessments'] = 'Vurderinger i workshop';
$string['workshopcomments'] = 'Kommentarer i workshop';
$string['workshopfeedback'] = 'Tilbakemeldinger i workshop';
$string['workshopsubmissions'] = 'Innleveringer i workshop';
$string['yourassessments'] = 'Dine vurderinger';
$string['yourassessmentsofexamplesfromtheteacher'] = 'Dine vurderinger av eksempler fra $a';
$string['yourfeedbackgoeshere'] = 'Skriv din tilbakemelding her';

?>
